@@ -31,6 +31,7 @@
 (require 'nnmail)
 (require 'nnoo)
 (require 'gnus-util)
+(require 'mm-util)
 (eval-when-compile (require 'cl))
 
 (nnoo-declare nndoc)
@@ -289,7 +290,7 @@ from the document.")
 	(mm-enable-multibyte)
 	(erase-buffer)
 	(if (stringp nndoc-address)
-	    (nnheader-insert-file-contents nndoc-address)
+	    (mm-insert-file-contents nndoc-address)
 	  (insert-buffer-substring nndoc-address))
 	(run-hooks 'nndoc-open-document-hook))))
     ;; Initialize the nndoc structures according to this new document.
